@@ -1,9 +1,10 @@
+from copy import deepcopy
 try:
     from .sanitizeNames import sanitizeName
 except:
     from plugins.sanitizeNames import sanitizeName
 
-def makeExpressionAbsolute(model_name, expression,connects):
+def makeExpressionAbsolute(model_name, expression,connects,entity,dimensions):
 
     seperator = '.'
 
@@ -12,18 +13,21 @@ def makeExpressionAbsolute(model_name, expression,connects):
 
     if type(expression) is list:
         for elem in expression:
-            makeExpressionAbsolute(model_name, elem,connects)
+            makeExpressionAbsolute(model_name, elem,connects,entity,dimensions)
 
     if type(expression) is dict:
         name = expression["name"]
         type_ = expression["type"]
 
         if "args" in expression.keys():
-            makeExpressionAbsolute(model_name, expression["args"],connects)
+            makeExpressionAbsolute(model_name, expression["args"],connects,entity, dimensions)
 
         if type_ == "identifier" or type_ == "array":
 
-            if not seperator in name:
+            if name in dimensions.keys(): # ignore dimension names
+                pass
+
+            elif not seperator in name:
                 expression["name"] = sanitizeName(model_name) + seperator + expression["name"] if len(model_name) > 0 else expression["name"]
 
             '''
