@@ -33,6 +33,13 @@ class InstanceManager:
     def is_valid_instance(self, instance_uuid):
         return instance_uuid in self._instances
 
+    def keep_instance_alive(self,instance_uuid):
+        if not self.is_valid_instance(instance_uuid):
+            return None
+        self._update_instance_timestamp(instance_uuid)
+        self._timeout_instances()
+        return None
+
     def get_instance(self,instance_uuid):
         if not self.is_valid_instance(instance_uuid):
             return None
@@ -45,7 +52,7 @@ class InstanceManager:
         if self.is_valid_instance(instance_uuid):
             self._instances[instance_uuid]["time"]= datetime.datetime.now()
 
-    def create_instance(self):
+    def create_instance(self,**timeout):
         """
         The method generates a universally unique identifier in hexadecimal, that is used as key for the instances.
 
@@ -55,10 +62,21 @@ class InstanceManager:
 
         self._timeout_instances()
 
+        timeout = {
+            "weeks": 0 if "weeks" not in timeout else timeout["weeks"],
+            "days": 0 if "days" not in timeout else timeout["days"],
+            "hours": 0 if "hours" not in timeout else timeout["hours"],
+            "minutes":  0 if "minutes" not in timeout else timeout["minutes"],
+            "seconds": 0 if "seconds" not in timeout else timeout["seconds"],
+            "milliseconds": 0 if "milliseconds" not in timeout else timeout["milliseconds"],
+            "microseconds":0 if "microseconds" not in timeout else timeout["microseconds"]
+        }
+
         instance_uuid = uuid.uuid1().hex
         self._instances[instance_uuid] = dict()
         self._instances[instance_uuid]["instance"] = self._make_bptk()
-        self._instances[instance_uuid]["time"] = dict()
+        self._instances[instance_uuid]["time"] = datetime.datetime.now()
+        self._instances[instance_uuid]["timeout"]=timeout
 
         return instance_uuid
 
@@ -71,14 +89,19 @@ class InstanceManager:
                 Means that the specified time has already passed, and the session should be terminated.
         """
 
-        timeout = datetime.timedelta(minutes=5)  # Terminate the session after 5 minutes
 
         for key in tuple(self._instances.keys()): # we're iterating over a copy of the keys here to ensure we don't delete an element from the dictionary while iterating through it.
             current_time = datetime.datetime.now()
-            last_call_time = self._instances[key]["time"]
-            if last_call_time:
-                if current_time >= last_call_time + timeout:
-                    del self._instances[key]
+
+            if "time" in self._instances[key]:
+                if "timeout" in self._instances[key]:
+                    timeout = datetime.timedelta(**self._instances[key]["timeout"])
+                else:
+                    timeout = datetime.timedelta(minutes=5)  # Terminate the session after 5 minutes
+                last_call_time = self._instances[key]["time"]
+                if last_call_time:
+                    if current_time >= last_call_time + timeout:
+                        del self._instances[key]
 
 ######################
 ##  REST API CLASS  ##
@@ -112,6 +135,7 @@ class BptkServer(Flask):
         self.route("/<instance_uuid>/begin-session", methods=['POST'], strict_slashes=False)(self._begin_session_resource)
         self.route("/<instance_uuid>/end-session", methods=['POST'], strict_slashes=False)(self._end_session_resource)
         self.route("/<instance_uuid>/session-results", methods=['GET'], strict_slashes=False)(self._session_results_resource)
+        self.route("/<instance_uuid>/keep-alive", methods=['POST'], strict_slashes=False)(self._keep_alive_resource)
 
     def _home_resource(self):
         """
@@ -327,13 +351,23 @@ class BptkServer(Flask):
     def _start_instance_resource(self):
         """
         This endpoint starts a new instance of BPTK on the server side, so that simulations can run in a "private" session. The endpoint returns an instance_id, which is needed to identify the instance in later calls.
+
+        Arguments: timeout (dict,optional)
+            The timeout period after which the instance is delete if it is not accessed in the meantime. The timer is reset every time the instance is accessed. The timeout dictionary can have the following keys: weeks, days, hours, minutes, seconds, milliseconds, microseconds. Values must be integers.
         """
 
         # store the new instance in the instance dictionary.
-        instance_uuid = self._instance_manager.create_instance()
+
+        timeout = {"weeks":0, "days":0, "hours":0, "minutes":5,"seconds":0,"milliseconds":0,"microseconds":0}
+        if request.is_json:
+            content = request.get_json()
+            if "timeout" in content:
+                timeout = content["timeout"]
+
+        instance_uuid = self._instance_manager.create_instance(**timeout)
 
         if instance_uuid is not None:
-            resp = make_response(f'{{"instance_uuid":"{instance_uuid}"}}', 200)
+            resp = make_response(f'{{"instance_uuid":"{instance_uuid}","timeout":"{timeout}"}}', 200)
         else:
             resp = make_response('{"error": "instance could not be started"}', 500)
 
@@ -471,3 +505,20 @@ class BptkServer(Flask):
         resp.headers['Content-Type'] = 'application/json'
         resp.headers['Access-Control-Allow-Origin']='*'
         return resp
+
+    def _keep_alive_resource(self,instance_uuid):
+        """
+        This endpoint sets the "last accessed time" of the instance to the current time to prevent the instance from timeing out.
+
+        Arguments: None
+        """
+
+        if not self._instance_manager.is_valid_instance(instance_uuid):
+            resp = make_response('{"error": "expecting a valid instance id to be given"}', 500)
+        else:
+            self._instance_manager.keep_instance_alive(instance_uuid)
+            resp = make_response('{"msg":"instance timer reset"}',200)
+
+        resp.headers['Content-Type'] = 'application/json'
+        resp.headers['Access-Control-Allow-Origin']='*'
+        return resp
